@@ -12,7 +12,7 @@ use File::Spec     ();
 use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 has base_url      => '/packed/';
 has minify        => 0;
@@ -86,11 +86,7 @@ sub register {
   if (NO_CACHE) {
     $app->log->info('AssetPack Will rebuild assets on each request in memory');
     $self->out_dir('');
-    $self->_assets_from_memory($app);
-  }
-  elsif (!$self->out_dir) {
-    $app->log->warn('AssetPack will store assets in memory');
-    $self->_assets_from_memory($app);
+    $self->_assets_from_memory;
   }
 
   $app->helper(
@@ -116,9 +112,10 @@ sub _assets {
 }
 
 sub _assets_from_memory {
-  my ($self, $app) = @_;
+  my $self = shift;
 
-  $app->hook(
+  $self->{assets_from_memory_added} = 1;
+  $self->_app->hook(
     before_routes => sub {
       my $c    = shift;
       my $path = $c->req->url->path;
@@ -221,7 +218,7 @@ sub _make_error_asset {
     $err =~ s!\n!\\A!g;
     $err =~ s!\s! !g;
     return
-      qq(html:before{background:#f00;color:#fff;font-size:14pt;position:absolute;padding:20px;z-index:9999;content:"$err";});
+      qq(html:before{background:#f00;color:#fff;font-size:14pt;position:fixed;padding:20px;z-index:9999;content:"$err";});
   }
 }
 
@@ -263,6 +260,11 @@ sub _process {
     };
   }
 
+  if (!$self->{assets_from_memory_added} and !$self->out_dir) {
+    $self->_app->log->warn('AssetPack will store assets in memory');
+    $self->_assets_from_memory;
+  }
+
   $asset->in_memory(!$self->out_dir)->save;
   $self->_app->log->info("Built asset for $moniker");
   $asset;
@@ -327,7 +329,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.54
+0.55
 
 =head1 SYNOPSIS
 
